@@ -4,9 +4,9 @@ var helpers = require("../../helpers/helpers");
 
 exports["Canada/Yukon"] = {
 
-	"guess:by:offset" : helpers.makeTestGuess("Canada/Yukon", { offset: true, expect: "America/Los_Angeles" }),
+	"guess:by:offset" : helpers.makeTestGuess("Canada/Yukon", { offset: true, expect: "America/Whitehorse" }),
 
-	"guess:by:abbr" : helpers.makeTestGuess("Canada/Yukon", { abbr: true, expect: "America/Los_Angeles" }),
+	"guess:by:abbr" : helpers.makeTestGuess("Canada/Yukon", { abbr: true, expect: "America/Whitehorse" }),
 
 	"1918" : helpers.makeTestYear("Canada/Yukon", [
 		["1918-04-14T10:59:59+00:00", "01:59:59", "YST", 540],
@@ -328,127 +328,6 @@ exports["Canada/Yukon"] = {
 
 	"2020" : helpers.makeTestYear("Canada/Yukon", [
 		["2020-03-08T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2020-03-08T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2020-11-01T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2020-11-01T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2021" : helpers.makeTestYear("Canada/Yukon", [
-		["2021-03-14T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2021-03-14T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2021-11-07T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2021-11-07T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2022" : helpers.makeTestYear("Canada/Yukon", [
-		["2022-03-13T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2022-03-13T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2022-11-06T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2022-11-06T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2023" : helpers.makeTestYear("Canada/Yukon", [
-		["2023-03-12T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2023-03-12T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2023-11-05T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2023-11-05T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2024" : helpers.makeTestYear("Canada/Yukon", [
-		["2024-03-10T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2024-03-10T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2024-11-03T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2024-11-03T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2025" : helpers.makeTestYear("Canada/Yukon", [
-		["2025-03-09T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2025-03-09T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2025-11-02T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2025-11-02T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2026" : helpers.makeTestYear("Canada/Yukon", [
-		["2026-03-08T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2026-03-08T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2026-11-01T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2026-11-01T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2027" : helpers.makeTestYear("Canada/Yukon", [
-		["2027-03-14T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2027-03-14T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2027-11-07T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2027-11-07T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2028" : helpers.makeTestYear("Canada/Yukon", [
-		["2028-03-12T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2028-03-12T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2028-11-05T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2028-11-05T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2029" : helpers.makeTestYear("Canada/Yukon", [
-		["2029-03-11T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2029-03-11T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2029-11-04T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2029-11-04T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2030" : helpers.makeTestYear("Canada/Yukon", [
-		["2030-03-10T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2030-03-10T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2030-11-03T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2030-11-03T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2031" : helpers.makeTestYear("Canada/Yukon", [
-		["2031-03-09T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2031-03-09T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2031-11-02T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2031-11-02T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2032" : helpers.makeTestYear("Canada/Yukon", [
-		["2032-03-14T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2032-03-14T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2032-11-07T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2032-11-07T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2033" : helpers.makeTestYear("Canada/Yukon", [
-		["2033-03-13T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2033-03-13T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2033-11-06T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2033-11-06T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2034" : helpers.makeTestYear("Canada/Yukon", [
-		["2034-03-12T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2034-03-12T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2034-11-05T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2034-11-05T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2035" : helpers.makeTestYear("Canada/Yukon", [
-		["2035-03-11T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2035-03-11T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2035-11-04T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2035-11-04T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2036" : helpers.makeTestYear("Canada/Yukon", [
-		["2036-03-09T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2036-03-09T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2036-11-02T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2036-11-02T09:00:00+00:00", "01:00:00", "PST", 480]
-	]),
-
-	"2037" : helpers.makeTestYear("Canada/Yukon", [
-		["2037-03-08T09:59:59+00:00", "01:59:59", "PST", 480],
-		["2037-03-08T10:00:00+00:00", "03:00:00", "PDT", 420],
-		["2037-11-01T08:59:59+00:00", "01:59:59", "PDT", 420],
-		["2037-11-01T09:00:00+00:00", "01:00:00", "PST", 480]
+		["2020-03-08T10:00:00+00:00", "03:00:00", "MST", 420]
 	])
 };
\ No newline at end of file
