@@ -8,5 +8,8 @@ exports["Indian/Maldives"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Indian/Maldives", { abbr: true, expect: "Asia/Karachi" }),
 
-
+	"1959" : helpers.makeTestYear("Indian/Maldives", [
+		["1959-12-31T19:05:59+00:00", "23:59:59", "MMT", -294],
+		["1959-12-31T19:06:00+00:00", "00:06:00", "+05", -300]
+	])
 };
\ No newline at end of file
